==> igniteui-react-16.16.2.tgz: package/esm2015/lib/Avatar.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { BaseElement } from "./BaseElement";
import { WCNativeHelper } from "./WCNativeHelper";
import { enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { AvatarShape_$type } from "./AvatarShape";
import { SizableComponentSize_$type } from "./SizableComponentSize";
/**
 * @hidden
 */
export let Avatar = /*@__PURE__*/ (() => {
    class Avatar extends BaseElement {
        constructor() {
            super(...arguments);
            this.c = new WCNativeHelper();
            this.e = null;
        }
        get d() {
            return this.c;
        }
        get nativeElement() {
            return this.e;
        }
        set nativeElement(a) {
            this.e = a;
            this.c.d = this.e;
        }
        get i() {
            let ret_ = this.d.c("src");
            return ret_;
        }
        set i(a) {
            let value_ = a;
            this.d.i("src", value_);
        }
        get g() {
            let ret_ = this.d.c("alt");
            return ret_;
        }
        set g(a) {
            let value_ = a;
            this.d.i("alt", value_);
        }
        get h() {
            let ret_ = this.d.c("initials");
            return ret_;
        }
        set h(a) {
            let value_ = a;
            this.d.i("initials", value_);
        }
        get a() {
            let ret_ = this.d.c("shape");
            ret_ = enumGetBox(AvatarShape_$type, EnumUtil.getEnumValue(AvatarShape_$type, EnumUtil.parse(AvatarShape_$type, ret_.toString(), true)));
            return EnumUtil.getEnumValue(AvatarShape_$type, ret_);
        }
        set a(a) {
            let value_ = enumGetBox(AvatarShape_$type, a);
            value_ = WCNativeHelper.e(value_.toString());
            this.d.i("shape", value_);
        }
        get b() {
            let ret_ = this.d.c("size");
            ret_ = enumGetBox(SizableComponentSize_$type, EnumUtil.getEnumValue(SizableComponentSize_$type, EnumUtil.parse(SizableComponentSize_$type, ret_.toString(), true)));
            return EnumUtil.getEnumValue(SizableComponentSize_$type, ret_);
        }
        set b(a) {
            let value_ = enumGetBox(SizableComponentSize_$type, a);
            value_ = WCNativeHelper.e(value_.toString());
            this.d.i("size", value_);
        }
    }
    Avatar.$t = /*@__PURE__*/ markType(Avatar, 'Avatar', BaseElement.$);
    return Avatar;
})();

==> igniteui-react-18.6.0.tgz: package/esm2015/lib/Avatar.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { BaseElement } from "./BaseElement";
import { WCNativeHelper } from "./WCNativeHelper";
import { enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { AvatarShape_$type } from "./AvatarShape";
import { SizableComponentSize_$type } from "./SizableComponentSize";
/**
 * @hidden
 */
export let Avatar = /*@__PURE__*/ (() => {
    class Avatar extends BaseElement {
        constructor() {
            super(...arguments);
            this.c = new WCNativeHelper();
            this.e = null;
        }
        get d() {
            return this.c;
        }
        get nativeElement() {
            return this.e;
        }
        set nativeElement(a) {
            this.e = a;
            this.c.o = this.e;
        }
        setNativeElement(a) {
            this.nativeElement = a;
        }
        get i() {
            let ret_ = this.d.n("src");
            return ret_;
        }
        set i(a) {
            let value_ = a;
            this.d.v("src", value_);
        }
        get g() {
            let ret_ = this.d.n("alt");
            return ret_;
        }
        set g(a) {
            let value_ = a;
            this.d.v("alt", value_);
        }
        get h() {
            let ret_ = this.d.n("initials");
            return ret_;
        }
        set h(a) {
            let value_ = a;
            this.d.v("initials", value_);
        }
        get a() {
            let ret_ = this.d.n("shape");
            if ((ret_ === undefined && this.___rawMode)) {
                return undefined;
            }
            ret_ = enumGetBox(AvatarShape_$type, EnumUtil.getEnumValue(AvatarShape_$type, this.d.f(AvatarShape_$type, ret_)));
            return EnumUtil.getEnumValue(AvatarShape_$type, ret_);
        }
        set a(a) {
            let value_ = enumGetBox(AvatarShape_$type, a);
            value_ = WCNativeHelper.camel(value_.toString());
            this.d.v("shape", value_);
        }
        get b() {
            let ret_ = this.d.n("size");
            if ((ret_ === undefined && this.___rawMode)) {
                return undefined;
            }
            ret_ = enumGetBox(SizableComponentSize_$type, EnumUtil.getEnumValue(SizableComponentSize_$type, this.d.f(SizableComponentSize_$type, ret_)));
            return EnumUtil.getEnumValue(SizableComponentSize_$type, ret_);
        }
        set b(a) {
            let value_ = enumGetBox(SizableComponentSize_$type, a);
            value_ = WCNativeHelper.camel(value_.toString());
            this.d.v("size", value_);
        }
    }
    Avatar.$t = /*@__PURE__*/ markType(Avatar, 'Avatar', BaseElement.$);
    return Avatar;
})();
